@@ -156,3 +156,12 @@ class FlaviusData(FlaviusBase):
     def __init__(self):
         super(FlaviusData, self).__init__(search_url='', create_url=conf.FLAVIUS_API_DATA_CREATE,
                                           update_url='', delete_url='')
+
+
+class FlaviusPage(FlaviusBase):
+    """
+    Flaviusのpageテーブルに関連するAPIを実行するクラス
+    """
+    def __init__(self):
+        super(FlaviusPage, self).__init__(search_url=conf.FLAVIUS_API_PAGE_FETCH,
+                                          create_url='', update_url='', delete_url='')
