@@ -58,6 +58,10 @@ class Settings:
     def FLAVIUS_API_DATA_CREATE(self):
         return getattr(settings, "FLAVIUS_API_DATA_CREATE", 'api/data_add.php')
 
+    @property
+    def FLAVIUS_API_PAGE_FETCH(self):
+        return getattr(settings, "FLAVIUS_API_PAGE_FETCH", 'api/pages.php')
+
     @property
     def EXCLUDE_TAX(self):
         return getattr(settings, "EXCLUDE_TAX", '91100')
